import React from 'react'

import fuzzy from 'fuzzy';
import Infinite from 'react-infinite';

import ListFilter from './filter'
import ListPoster from './poster'

export default class ListPosters extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      elementHeight: 150,
      elementWidth: 70,
      containerWidth: 0,
      elementPerRaw: 1,
      fakeElementHeight: 100,
    };
    this.updateDimensions = this.updateDimensions.bind(this);
  }
  updateDimensions() {
    let thumbnails = document.getElementsByClassName("thumbnail");
    if (thumbnails.length === 0) {
      return
    }
    let containers = document.getElementsByClassName("posters-infinite-container");
    if (containers.length === 0) {
      return
    }
    let elementHeight = thumbnails[0].parentNode.clientHeight;
    let elementWidth = thumbnails[0].parentNode.clientWidth;
    let containerWidth = containers[0].clientWidth;
    let elementPerRaw = Math.round(containerWidth/elementWidth);
    let fakeElementHeight = Math.round(elementHeight/elementPerRaw);
    this.setState({
      elementHeight: elementHeight,
      elementWidth: elementWidth,
      containerWidth: containerWidth,
      elementPerRaw: elementPerRaw,
      fakeElementHeight: fakeElementHeight,
    });
  }
  componentDidMount() {
    window.addEventListener("resize", this.updateDimensions);
    this.updateDimensions();
  }
  componentWillUnmount() {
    window.removeEventListener("resize", this.updateDimensions);
  }

  render() {
    let elmts = this.props.data.slice();
    const listSize = elmts.length;
    const colSize = (listSize !== 0) ? "col-xs-5 col-md-8" : "col-xs-12";

    // Filter the list of elements
    if (this.props.filter !== "") {
      const filtered = fuzzy.filter(this.props.filter, elmts, {
        extract: (el) => el.title
      });
      elmts = filtered.map((el) => el.original);
    }

    return (
      <div className={colSize}>
        <ListFilter
          listSize={listSize}
          formModel={this.props.formModel}
          controlModel={this.props.controlModel}
          controlPlaceHolder={this.props.controlPlaceHolder}
        />
        {elmts.length === 0 &&
            <div className="jumbotron">
              <h2>No result</h2>
            </div>
        }
        <Infinite
          elementHeight={this.state.fakeElementHeight}
          infiniteLoadBeginEdgeOffset={200}
          useWindowAsScrollContainer
          className="row posters-infinite-container"
        >
          {elmts.map(function(el, index) {
            const selected = (el.imdb_id === this.props.selectedImdbId) ? true : false;
            return (
              <ListPoster
                index={index}
                data={el}
                key={el.imdb_id}
                selected={selected}
                onClick={() => this.props.onClick(el.imdb_id)}
              />
            )}
            , this)}
        </Infinite>
      </div>
    );
  }
}
